@@ -1,5 +1,5 @@
 from .auth import SubstackAuth
-from .category import Category
+from .category import Category, list_all_categories
 from .newsletter import Newsletter
 from .post import Post
 from .user import User, resolve_handle_redirect
@@ -11,4 +11,5 @@ __all__ = [
     "Newsletter",
     "SubstackAuth",
     "resolve_handle_redirect",
+    "list_all_categories",
 ]
