@@ -52,9 +52,12 @@ class Newsletter:
             The response object from the request
         """
         if self.auth and self.auth.authenticated:
-            return self.auth.get(endpoint, **kwargs)
+            resp = self.auth.get(endpoint, **kwargs)
         else:
-            return requests.get(endpoint, headers=HEADERS, **kwargs)
+            resp = requests.get(endpoint, headers=HEADERS, **kwargs)
+
+        sleep(2)  # Be polite to the server
+        return resp
 
     def _fetch_paginated_posts(
         self, params: Dict[str, str], limit: Optional[int] = None, page_size: int = 15
@@ -92,9 +95,7 @@ class Newsletter:
 
             # Make the request
             response = self._make_request(endpoint, timeout=30)
-
-            if response.status_code != 200:
-                break
+            response.raise_for_status()
 
             items = response.json()
             if not items:
@@ -114,9 +115,6 @@ class Newsletter:
             if len(items) < batch_size:
                 more_items = False
 
-            # Be nice to the API
-            sleep(0.5)
-
         # Instead of creating Post objects directly, return the URLs
         # The caller will create Post objects as needed
         return results
@@ -204,9 +202,7 @@ class Newsletter:
         # Now get the recommendations
         endpoint = f"{self.url}/api/v1/recommendations/from/{publication_id}"
         response = self._make_request(endpoint, timeout=30)
-
-        if response.status_code != 200:
-            return []
+        response.raise_for_status()
 
         recommendations = response.json()
         if not recommendations:
